---
layout: post
title: Draft post
date: 2020-12-27
topics: stasis
---

A draft.

<!--excerpt-->

This is a draft, it will only be built if the `--drafts` option is passed to `stasis build`, as in:

    stasis build --drafts

Note that if you do not want drafts to appear in the deployed site, you will need to run `stasis clean` and then build again without the drafts option.
